Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Compare ¶
func Compare(expected, actual *SchemaFingerprint) error
Compare compares two schema fingerprints and returns an error if they don't match
Types ¶
type SchemaFingerprint ¶
type SchemaFingerprint struct {
Hash string `json:"hash"` // SHA256 of normalized IR
}
SchemaFingerprint represents a fingerprint of a database schema state
func ComputeFingerprint ¶
func ComputeFingerprint(schemaIR *ir.IR, schemaName string) (*SchemaFingerprint, error)
ComputeFingerprint generates a fingerprint for the given IR and schema
func (*SchemaFingerprint) String ¶
func (f *SchemaFingerprint) String() string
String returns a human-readable representation of the fingerprint
Click to show internal directories.
Click to hide internal directories.